# V1alpha1Sequence

Sequence expands a workflow step into numeric range
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**count** | **str** | Count is number of elements in the sequence (default: 0). Not to be used with end | [optional] 
**end** | **str** | Number at which to end the sequence (default: 0). Not to be used with Count | [optional] 
**format** | **str** | Format is a printf format string to format the value in the sequence | [optional] 
**start** | **str** | Number at which to start the sequence (default: 0) | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


